==> haskell-bimap-0.4.0-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bimap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bimap
version:              0.4.0
visibility:           public
id:                   bimap-0.4.0-4pMzJxLXYOML4J4uYpVdFc
key:                  bimap-0.4.0-4pMzJxLXYOML4J4uYpVdFc
license:              BSD-3-Clause
copyright:            Stuart Cook and contributors 2008, Joel Williamson 2015
maintainer:           Joel Williamson <joel@joelwilliamson.ca>
author:               Stuart Cook and contributors 2008, Joel Williamson 2015
homepage:             https://github.com/joelwilliamson/bimap
synopsis:             Bidirectional mapping between two key types
description:
    A data structure representing a bidirectional mapping between two
    key types. Each value in the bimap is associated with exactly one
    value of the opposite type.

category:             Data
abi:                  384e9d3886cd5122dde15eb62e39833f
exposed:              True
exposed-modules:      Data.Bimap
import-dirs:          /usr/lib/ghc-8.10.2/site-local/bimap-0.4.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/bimap-0.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/bimap-0.4.0
hs-libraries:         HSbimap-0.4.0-4pMzJxLXYOML4J4uYpVdFc
depends:
    base-4.14.1.0 containers-0.6.2.1 deepseq-1.4.4.0 exceptions-0.10.4

haddock-interfaces:   /usr/share/doc/haskell-bimap/html/bimap.haddock
haddock-html:         /usr/share/doc/haskell-bimap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bimap-0.4.0-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bimap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bimap
version:              0.4.0
visibility:           public
id:                   bimap-0.4.0-GD6MV3tRsi7Cee2wRk7zzt
key:                  bimap-0.4.0-GD6MV3tRsi7Cee2wRk7zzt
license:              BSD-3-Clause
copyright:            Stuart Cook and contributors 2008, Joel Williamson 2015
maintainer:           Joel Williamson <joel@joelwilliamson.ca>
author:               Stuart Cook and contributors 2008, Joel Williamson 2015
homepage:             https://github.com/joelwilliamson/bimap
synopsis:             Bidirectional mapping between two key types
description:
    A data structure representing a bidirectional mapping between two
    key types. Each value in the bimap is associated with exactly one
    value of the opposite type.

category:             Data
abi:                  29bfa4796dba5b066dbbecc0f1862710
exposed:              True
exposed-modules:      Data.Bimap
import-dirs:          /usr/lib/ghc-8.10.2/site-local/bimap-0.4.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/bimap-0.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/bimap-0.4.0
hs-libraries:         HSbimap-0.4.0-GD6MV3tRsi7Cee2wRk7zzt
depends:
    base-4.14.1.0 containers-0.6.2.1 deepseq-1.4.4.0 exceptions-0.10.4

haddock-interfaces:   /usr/share/doc/haskell-bimap/html/bimap.haddock
haddock-html:         /usr/share/doc/haskell-bimap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
